@@ -18,11 +18,12 @@
 
 #include "common/debugging.h"
 #include "common/hacks.h"
+#include "common/mkvtoolnix_version.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
 #include "common/version.h"
 
-#define VERSIONNAME "Leave It"
+#define VERSIONNAME "The Silent Type"
 
 version_number_t::version_number_t(const std::string &s)
   : valid{}
@@ -101,6 +102,13 @@ version_number_t::operator <(const version_number_t &cmp)
   return compare(cmp) == -1;
 }
 
+bool
+version_number_t::operator ==(const version_number_t &cmp)
+  const
+{
+  return compare(cmp) == 0;
+}
+
 std::string
 version_number_t::to_string()
   const
@@ -135,7 +143,7 @@ get_version_info(const std::string &program,
 
   if (!program.empty())
     info.push_back(program);
-  info.push_back(fmt::format("v{0} ('{1}')", PACKAGE_VERSION, VERSIONNAME));
+  info.push_back(fmt::format("v{0} ('{1}')", MKVTOOLNIX_VERSION, VERSIONNAME));
 
   if (flags & vif_architecture)
     info.push_back(fmt::format("{0}-bit", __SIZEOF_POINTER__ * 8));
@@ -145,12 +153,12 @@ get_version_info(const std::string &program,
 
 int
 compare_current_version_to(const std::string &other_version_str) {
-  return version_number_t(PACKAGE_VERSION).compare(version_number_t(other_version_str));
+  return version_number_t(MKVTOOLNIX_VERSION).compare(version_number_t(other_version_str));
 }
 
 version_number_t
 get_current_version() {
-  return version_number_t(PACKAGE_VERSION);
+  return version_number_t(MKVTOOLNIX_VERSION);
 }
 
 mtx_release_version_t
