@@ -170,9 +170,9 @@ ebml_converter_c::parse_uint(parser_context_t &ctx) {
     throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), Y("An unsigned integer was expected.") };
 
   if (ctx.limits.has_min && (value < static_cast<uint64_t>(ctx.limits.min)))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed value: %1%, actual value: %2%")) % ctx.limits.min % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Minimum allowed value: {0}, actual value: {1}"), ctx.limits.min, value) };
   if (ctx.limits.has_max && (value > static_cast<uint64_t>(ctx.limits.max)))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed value: %1%, actual value: %2%")) % ctx.limits.max % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Maximum allowed value: {0}, actual value: {1}"), ctx.limits.max, value) };
 
   static_cast<EbmlUInteger &>(ctx.e).SetValue(value);
 }
@@ -184,9 +184,9 @@ ebml_converter_c::parse_int(parser_context_t &ctx) {
     throw malformed_data_x{ ctx.name, ctx.node.offset_debug() };
 
   if (ctx.limits.has_min && (value < ctx.limits.min))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed value: %1%, actual value: %2%")) % ctx.limits.min % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Minimum allowed value: {0}, actual value: {1}"), ctx.limits.min, value) };
   if (ctx.limits.has_max && (value > ctx.limits.max))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed value: %1%, actual value: %2%")) % ctx.limits.max % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Maximum allowed value: {0}, actual value: {1}"), ctx.limits.max, value) };
 
   static_cast<EbmlSInteger &>(ctx.e).SetValue(value);
 }
@@ -205,19 +205,19 @@ void
 ebml_converter_c::parse_timestamp(parser_context_t &ctx) {
   int64_t value;
   if (!::parse_timestamp(strip_copy(ctx.content), value)) {
-    auto details = (boost::format(Y("Expected a time in the following format: HH:MM:SS.nnn "
-                                    "(HH = hour, MM = minute, SS = second, nnn = millisecond up to nanosecond. "
-                                    "You may use up to nine digits for 'n' which would mean nanosecond precision). "
-                                    "You may omit the hour as well. Found '%1%' instead. Additional error message: %2%"))
-                    % ctx.content % timestamp_parser_error.c_str()).str();
+    auto details = fmt::format(Y("Expected a time in the following format: HH:MM:SS.nnn "
+                                 "(HH = hour, MM = minute, SS = second, nnn = millisecond up to nanosecond. "
+                                 "You may use up to nine digits for 'n' which would mean nanosecond precision). "
+                                 "You may omit the hour as well. Found '{0}' instead. Additional error message: {1}"),
+                               ctx.content, timestamp_parser_error.c_str());
 
     throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), details };
   }
 
   if (ctx.limits.has_min && (value < ctx.limits.min))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed value: %1%, actual value: %2%")) % ctx.limits.min % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Minimum allowed value: {0}, actual value: {1}"), ctx.limits.min, value) };
   if (ctx.limits.has_max && (value > ctx.limits.max))
-    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed value: %1%, actual value: %2%")) % ctx.limits.max % value).str() };
+    throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Maximum allowed value: {0}, actual value: {1}"), ctx.limits.max, value) };
 
   static_cast<EbmlUInteger &>(ctx.e).SetValue(value);
 }
@@ -226,9 +226,9 @@ void
 ebml_converter_c::parse_binary(parser_context_t &ctx) {
   auto test_min_max = [&ctx](auto const &test_content) {
     if (ctx.limits.has_min && (test_content.length() < static_cast<size_t>(ctx.limits.min)))
-      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Minimum allowed length: %1%, actual length: %2%")) % ctx.limits.min % test_content.length()).str() };
+      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Minimum allowed length: {0}, actual length: {1}"), ctx.limits.min, test_content.length()) };
     if (ctx.limits.has_max && (test_content.length() > static_cast<size_t>(ctx.limits.max)))
-      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Maximum allowed length: %1%, actual length: %2%")) % ctx.limits.max % test_content.length()).str() };
+      throw out_of_range_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Maximum allowed length: {0}, actual length: {1}"), ctx.limits.max, test_content.length()) };
   };
 
   ctx.handled_attributes["format"] = true;
@@ -253,7 +253,7 @@ ebml_converter_c::parse_binary(parser_context_t &ctx) {
       static_cast<EbmlBinary &>(ctx.e).CopyBuffer(reinterpret_cast<binary const *>(content.c_str()), size);
 
     } catch (mtx::mm_io::exception &) {
-      throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Could not open/read the file '%1%'.")) % file_name).str() };
+      throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Could not open/read the file '{0}'."), file_name) };
     }
 
     return;
@@ -286,7 +286,7 @@ ebml_converter_c::parse_binary(parser_context_t &ctx) {
     }
 
   } else if (format != "ascii")
-    throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), (boost::format(Y("Invalid 'format' attribute '%1%'.")) % format).str() };
+    throw malformed_data_x{ ctx.name, ctx.node.offset_debug(), fmt::format(Y("Invalid 'format' attribute '{0}'."), format) };
 
   test_min_max(content);
 
@@ -325,7 +325,7 @@ ebml_converter_c::to_xml_recursively(pugi::xml_node &parent,
 
   else {
     parent.remove_child(new_node);
-    parent.append_child(pugi::node_comment).set_value((boost::format(" unknown EBML element '%1%' ") % name).str().c_str());
+    parent.append_child(pugi::node_comment).set_value(fmt::format(" unknown EBML element '{0}' ", name).c_str());
   }
 }
 
@@ -338,7 +338,7 @@ ebml_converter_c::to_ebml(std::string const &file_name,
     return ebml_master_cptr();
 
   if (root_name != root_node.name())
-    throw conversion_x{boost::format(Y("The root element must be <%1%>.")) % root_name};
+    throw conversion_x{fmt::format(Y("The root element must be <{0}>."), root_name)};
 
   ebml_master_cptr ebml_root{new KaxSegment};
 
@@ -498,13 +498,13 @@ ebml_converter_c::dump_semantics_recursively(int level,
 
     if (limits->second.has_min && limits->second.has_max) {
       if (limits->second.min == limits->second.max)
-        limits_str = (boost::format("%2% == %1%")        % limits->second.min                      % label).str();
+        limits_str = fmt::format("{1} == {0}",        limits->second.min,                     label);
       else
-        limits_str = (boost::format("%1% <= %3% <= %2%") % limits->second.min % limits->second.max % label).str();
+        limits_str = fmt::format("{0} <= {2} <= {1}", limits->second.min, limits->second.max, label);
     } else if (limits->second.has_min)
-      limits_str = (boost::format("%1% <= %2%")          % limits->second.min                      % label).str();
+      limits_str = fmt::format("{0} <= {1}",          limits->second.min,                     label);
     else
-      limits_str = (boost::format("%2% <= %1%")                               % limits->second.max % label).str();
+      limits_str = fmt::format("{1} <= {0}",                              limits->second.max, label);
 
     limits_str = ", valid range: "s + limits_str;
   }
@@ -517,7 +517,7 @@ ebml_converter_c::dump_semantics_recursively(int level,
             : dynamic_cast<EbmlBinary        *>(&element) ? "binary"
             :                                               "unknown";
 
-  mxinfo(boost::format("%1%%2% (%3%%4%)\n") % std::string(level * 2, ' ') % tag_name % type % limits_str);
+  mxinfo(fmt::format("{0}{1} ({2}{3})\n", std::string(level * 2, ' '), tag_name, type, limits_str));
 
   if (!dynamic_cast<EbmlMaster *>(&element) || visited_masters[tag_name])
     return;
