@@ -204,7 +204,7 @@ extract_cli_parser_c::set_simple_language() {
 
   auto language_idx = map_to_iso639_2_code(m_next_arg);
   if (0 > language_idx)
-    mxerror(fmt::format(Y("'{0}' is neither a valid ISO639-2 nor a valid ISO639-1 code. See 'mkvmerge --list-languages' for a list of all languages and their respective ISO639-2 codes.\n"), m_next_arg));
+    mxerror(fmt::format(Y("'{0}' is neither a valid ISO 639-2 nor a valid ISO 639-1 code. See 'mkvmerge --list-languages' for a list of all languages and their respective ISO 639-2 codes.\n"), m_next_arg));
 
   m_current_mode->m_simple_chapter_language.reset(g_iso639_languages[language_idx].iso639_2_code);
 }
@@ -378,21 +378,6 @@ extract_cli_parser_c::add_extraction_spec() {
   set_default_values();
 }
 
-void
-extract_cli_parser_c::verify_options_multiple_mode() {
-  for (auto const &mode_options : m_options.m_modes) {
-    if (!mtx::included_in(mode_options.m_extraction_mode, options_c::em_chapters, options_c::em_cuesheet, options_c::em_tags))
-      continue;
-
-    auto mode_name = mode_options.m_extraction_mode == options_c::em_chapters ? "chapters"
-                   : mode_options.m_extraction_mode == options_c::em_tags     ? "tags"
-                   :                                                            "cuesheet";
-
-    if (mode_options.m_output_file_name.empty())
-      mxerror(fmt::format(Y("Missing destination file name in argument '{0}'.\n"), mode_name));
-  }
-}
-
 options_c
 extract_cli_parser_c::run() {
   init_parser();
@@ -404,8 +389,5 @@ extract_cli_parser_c::run() {
   if (m_debug)
     m_options.dump();
 
-  if (m_cli_type == cli_type_e::multiple)
-    verify_options_multiple_mode();
-
   return m_options;
 }
