@@ -232,7 +232,7 @@ struct qtmp4_demuxer_c {
   codec_c codec;
   pcm_packetizer_c::pcm_format_e m_pcm_format;
 
-  int64_t time_scale, duration, global_duration, num_frames_from_trun;
+  int64_t time_scale, track_duration, global_duration, num_frames_from_trun;
   uint32_t sample_size;
 
   std::vector<qt_sample_t> sample_table;
@@ -264,7 +264,7 @@ struct qtmp4_demuxer_c {
   bool m_hevc_is_annex_b{};
   std::deque<int64_t> references;
   uint32_t a_channels, a_bitdepth;
-  float a_samplerate;
+  double a_samplerate;
   boost::optional<mtx::aac::audio_config_t> a_aac_audio_config;
   mtx::ac3::frame_c m_ac3_header;
   mtx::dts::header_t m_dts_header;
@@ -287,7 +287,7 @@ struct qtmp4_demuxer_c {
     , pos{0}
     , m_pcm_format{pcm_packetizer_c::little_endian_integer}
     , time_scale{1}
-    , duration{0}
+    , track_duration{0}
     , global_duration{0}
     , num_frames_from_trun{}
     , sample_size{0}
