@@ -15,8 +15,6 @@
 
 #include "common/common_pch.h"
 
-#include <boost/optional.hpp>
-
 #include "common/file_types.h"
 #include "common/chapters/chapters.h"
 #include "common/math_fwd.h"
@@ -24,6 +22,7 @@
 #include "merge/file_status.h"
 #include "merge/id_result.h"
 #include "merge/packet.h"
+#include "merge/probe_range_info.h"
 #include "merge/timestamp_factory.h"
 #include "merge/track_info.h"
 #include "merge/webm.h"
@@ -40,9 +39,9 @@ class generic_packetizer_c;
 
 #define show_demuxer_info() \
   if (verbose) \
-    mxinfo_fn(m_ti.m_fname, boost::format(Y("Using the demultiplexer for the format '%1%'.\n")) % get_format_name());
+    mxinfo_fn(m_ti.m_fname, fmt::format(Y("Using the demultiplexer for the format '{0}'.\n"), get_format_name()));
 #define show_packetizer_info(track_id, packetizer) \
-  mxinfo_tid(m_ti.m_fname, track_id, boost::format(Y("Using the output module for the format '%1%'.\n")) % packetizer->get_format_name());
+  mxinfo_tid(m_ti.m_fname, track_id, fmt::format(Y("Using the output module for the format '{0}'.\n"), packetizer->get_format_name()));
 
 class generic_reader_c {
 public:
@@ -60,6 +59,8 @@ public:
 
   int64_t m_reference_timestamp_tolerance;
 
+  probe_range_info_t m_probe_range_info{};
+
 protected:
   id_result_t m_id_results_container;
   std::vector<id_result_t> m_id_results_tracks, m_id_results_attachments, m_id_results_chapters, m_id_results_tags;
@@ -80,6 +81,7 @@ public:
   virtual timestamp_c const &get_timestamp_restriction_min() const;
   virtual timestamp_c const &get_timestamp_restriction_max() const;
 
+  virtual void set_probe_range_info(probe_range_info_t const &info);
   virtual void read_headers() = 0;
   virtual file_status_e read_next(generic_packetizer_c *ptzr, bool force = false);
   virtual void read_all();
