@@ -7,7 +7,7 @@
 namespace mtx { namespace gui { namespace Util {
 
 class CountryComboBox: public ComboBoxBase {
-  Q_OBJECT;
+  Q_OBJECT
 
 protected:
   explicit CountryComboBox(ComboBoxBasePrivate &d, QWidget *parent);
