@@ -5,7 +5,6 @@
 #include <QDialogButtonBox>
 
 class QComboBox;
-class QFont;
 class QIcon;
 class QLineEdit;
 class QPushButton;
@@ -39,6 +38,4 @@ void enableChildren(QObject *parent, bool enable);
 
 void addSegmentUIDFromFileToLineEdit(QWidget &parent, QLineEdit &lineEdit, bool append);
 
-QFont defaultUiFont();
-
 }}}
