@@ -18,10 +18,10 @@ class Tab;
 
 class TabPrivate;
 class Tab : public QWidget {
-  Q_OBJECT;
+  Q_OBJECT
 
 protected:
-  MTX_DECLARE_PRIVATE(TabPrivate);
+  MTX_DECLARE_PRIVATE(TabPrivate)
 
   std::unique_ptr<TabPrivate> const p_ptr;
 
@@ -39,7 +39,7 @@ public:
 
   virtual uint64_t queueProgress() const;
 
-  uint64_t id() const;
+  boost::optional<uint64_t> id() const;
 
   bool isSaveOutputEnabled() const;
   bool isCurrentJobTab() const;
