@@ -8,8 +8,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_PROPEDIT_CHANGE_H
-#define MTX_PROPEDIT_CHANGE_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -36,7 +35,7 @@ public:
   uint64_t m_ui_value;
   int64_t m_si_value;
   bool m_b_value;
-  bitvalue_c m_x_value;
+  mtx::bits::value_c m_x_value;
   double m_fp_value;
 
   EbmlMaster *m_master, *m_sub_sub_master, *m_sub_sub_sub_master;
@@ -76,5 +75,3 @@ protected:
 
   const EbmlSemantic *get_semantic();
 };
-
-#endif // MTX_PROPEDIT_CHANGE_H
