@@ -92,14 +92,14 @@ TEST(FourCC, CreationFromMmIo) {
   EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}})                               .value(fourcc_c::little_endian));
   EXPECT_EQ(little, fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}},       fourcc_c::little_endian).value(fourcc_c::little_endian));
 
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{big_m,    4})                                .value());
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{big_m,    4},        fourcc_c::big_endian)   .value());
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{big_m,    4})                                .value(fourcc_c::big_endian));
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{big_m,    4},        fourcc_c::big_endian)   .value(fourcc_c::big_endian));
-  EXPECT_EQ(little, fourcc_c(           new mm_mem_io_c{little_m, 4})                                .value());
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{little_m, 4},        fourcc_c::little_endian).value());
-  EXPECT_EQ(big,    fourcc_c(           new mm_mem_io_c{little_m, 4})                                .value(fourcc_c::little_endian));
-  EXPECT_EQ(little, fourcc_c(           new mm_mem_io_c{little_m, 4},        fourcc_c::little_endian).value(fourcc_c::little_endian));
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{big_m,    4}}.get())                         .value());
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{big_m,    4}}.get(), fourcc_c::big_endian)   .value());
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{big_m,    4}}.get())                         .value(fourcc_c::big_endian));
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{big_m,    4}}.get(), fourcc_c::big_endian)   .value(fourcc_c::big_endian));
+  EXPECT_EQ(little, fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}}.get())                         .value());
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}}.get(), fourcc_c::little_endian).value());
+  EXPECT_EQ(big,    fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}}.get())                         .value(fourcc_c::little_endian));
+  EXPECT_EQ(little, fourcc_c(mm_io_cptr{new mm_mem_io_c{little_m, 4}}.get(), fourcc_c::little_endian).value(fourcc_c::little_endian));
 
   auto big_io    = mm_io_cptr{new mm_mem_io_c{big_m,    4}};
   auto little_io = mm_io_cptr{new mm_mem_io_c{little_m, 4}};
@@ -166,8 +166,8 @@ TEST(FourCC, StringificationAsDescription) {
   EXPECT_EQ("0x1f207e7f \"? ~?\"",                      fourcc_c{0x1f207e7f}.description());
 
   EXPECT_EQ("0x63766964 \"cvid\": Cinepak",             fourcc_c{"cvid"}.description());
-  EXPECT_EQ("0x78323634 \"x264\": MPEG-4p10/AVC/h.264", fourcc_c{"x264"}.description());
-  EXPECT_EQ("0x58323634 \"X264\": MPEG-4p10/AVC/h.264", fourcc_c{"X264"}.description());
+  EXPECT_EQ("0x78323634 \"x264\": MPEG-4p10/AVC/H.264", fourcc_c{"x264"}.description());
+  EXPECT_EQ("0x58323634 \"X264\": MPEG-4p10/AVC/H.264", fourcc_c{"X264"}.description());
 
   EXPECT_EQ("0x00000000 \"????\": Uncompressed",        fourcc_c{0x00000000u}.description());
 }
